@@ -192,7 +192,7 @@ def FeedForward(dim, mult = 1., num_layers = 2, act = nn.ReLU):
 
         layers.append(nn.Linear(dim_in, dim_out))
 
-        if not is_last:
+        if is_last:
             continue
 
         layers.append(act())
